@@ -8,6 +8,20 @@ from six.moves import queue
 
 from voiceassistant.utils.datastruct import RollingWindowQueue
 
+_PAUSED = False
+
+
+def pause_microphone_stream() -> None:
+    """Pause microphone stream."""
+    global _PAUSED
+    _PAUSED = True
+
+
+def resume_microphone_stream() -> None:
+    """Resume microphone stream."""
+    global _PAUSED
+    _PAUSED = False
+
 
 class MicrophoneStream:
     """Opens a recording stream as a generator yielding the audio chunks."""
@@ -61,8 +75,9 @@ class MicrophoneStream:
         status_flags: int,
     ) -> Tuple:
         """Continuously collect data from the audio stream into the buffer."""
-        self._buff.put(in_data)
-        self._last_chunks.append(in_data)
+        if not _PAUSED:
+            self._buff.put(in_data)
+            self._last_chunks.append(in_data)
         return None, pyaudio.paContinue
 
     def read(self) -> bytes:
