@@ -9,23 +9,7 @@ from iterators import TimeoutIterator
 from voiceassistant.config import Config
 from voiceassistant.exceptions import SetupIncomplete
 from voiceassistant.interfaces.speech.microphone_stream import MicrophoneStream
-
-
-class RecognitionString(str):
-    """Modify string object to have `is_final` attribute.
-
-    Required to differentiate between cases where
-    continious speech recognition is still running
-    or whether recognition result is final.
-    """
-
-    is_final = False
-
-    def __new__(cls, value: str, is_final: bool):  # type: ignore
-        """Create recognition string object."""
-        self_obj = str.__new__(cls, value)
-        self_obj.is_final = is_final
-        return self_obj
+from voiceassistant.utils.datastruct import RecognitionString
 
 
 class SpeechToText:
